@@ -3,23 +3,14 @@ from typing import Union
 from terra_sdk.core import AccAddress
 from terra_sdk.core.auth import Account, LazyGradedVestingAccount
 
-from ._base import BaseAPI
+from ._base import BaseAsyncAPI, sync_bind
+
+__all__ = ["AsyncAuthAPI", "AuthAPI"]
 
 
-class AsyncAuthAPI(BaseAPI):
+class AsyncAuthAPI(BaseAsyncAPI):
     async def account_info(
         self, address: AccAddress
-    ) -> Union[Account, LazyGradedVestingAccount]:
-        result = await self._c._get(f"/auth/accounts/{address}")
-        if result["type"] == "core/Account":
-            return Account.from_data(result)
-        else:
-            return LazyGradedVestingAccount.from_data(result)
-
-
-class AuthAPI(BaseAPI):
-    def account_info(
-        self, address: AccAddress
     ) -> Union[Account, LazyGradedVestingAccount]:
         """Fetches the account information.
 
@@ -29,8 +20,18 @@ class AuthAPI(BaseAPI):
         Returns:
             Union[Account, LazyGradedVestingAccount]: account information
         """
-        result = self._c._get(f"/auth/accounts/{address}")
+        result = await self._c._get(f"/auth/accounts/{address}")
         if result["type"] == "core/Account":
             return Account.from_data(result)
         else:
             return LazyGradedVestingAccount.from_data(result)
+
+
+class AuthAPI(AsyncAuthAPI):
+    @sync_bind(AsyncAuthAPI.account_info)
+    def account_info(
+        self, address: AccAddress
+    ) -> Union[Account, LazyGradedVestingAccount]:
+        pass
+
+    account_info.__doc__ = AsyncAuthAPI.account_info.__doc__
